@@ -373,7 +373,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetLocationVolumeResponse:
-        r"""Gets aggregated data for a Location (
+        r"""Retrieves top Locations.
 
         Args:
             request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
@@ -421,7 +421,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowAggregationResponse:
-        r"""Aggregates tradeflow data across multiple dimensions
+        r"""Aggregates tradeflow data across multiple dimensions.
 
         Args:
             request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
@@ -469,7 +469,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowTimeseriesResponse:
-        r"""Gets aggregated trade flow timeseries by period
+        r"""Gets aggregated trade flow timeseries by period.
 
         Args:
             request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
@@ -520,7 +520,7 @@ class TradeFlowServiceClient(metaclass=TradeFlowServiceClientMeta):
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowHistogramResponse:
         r"""GetTradeFlowHistogramValues gets trade flow histogram
-        values by grouping
+        values by grouping.
 
         Args:
             request (oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest):
