@@ -271,7 +271,7 @@ class TradeFlowServiceGrpcTransport(TradeFlowServiceTransport):
             service.GetLocationVolumeResponse]:
         r"""Return a callable for the get location data method over gRPC.
 
-        Gets aggregated data for a Location (
+        Retrieves top Locations.
 
         Returns:
             Callable[[~.TradeFlowDataRequest],
@@ -297,7 +297,7 @@ class TradeFlowServiceGrpcTransport(TradeFlowServiceTransport):
             service.GetTradeFlowAggregationResponse]:
         r"""Return a callable for the get trade flow aggregation method over gRPC.
 
-        Aggregates tradeflow data across multiple dimensions
+        Aggregates tradeflow data across multiple dimensions.
 
         Returns:
             Callable[[~.TradeFlowDataRequest],
@@ -323,7 +323,7 @@ class TradeFlowServiceGrpcTransport(TradeFlowServiceTransport):
             service.GetTradeFlowTimeseriesResponse]:
         r"""Return a callable for the get trade flow timeseries method over gRPC.
 
-        Gets aggregated trade flow timeseries by period
+        Gets aggregated trade flow timeseries by period.
 
         Returns:
             Callable[[~.TradeFlowDataRequest],
@@ -350,7 +350,7 @@ class TradeFlowServiceGrpcTransport(TradeFlowServiceTransport):
         r"""Return a callable for the get trade flow histogram method over gRPC.
 
         GetTradeFlowHistogramValues gets trade flow histogram
-        values by grouping
+        values by grouping.
 
         Returns:
             Callable[[~.TradeFlowDataRequest],
